@@ -134,6 +134,15 @@ class AbstractDeployer:
 
         return addresses
 
+    def export_address_to_fift( self, path: str, name: str = "owner" ):
+        addresses = self.get_address()
+
+        with open( path, "w", encoding='utf-8' ) as f:
+            logger.info(f"🦘 Exporing address to {gr}{path}{rs}")
+            f.write( addresses[0][0].replace( ":", " ") + f" 2constant {name}_raw\n" )
+            f.write( f'"{addresses[0][1]}" constant {name}_address\n' )
+            f.write( f'"{addresses[0][2]}" constant {name}_no_bounce\n' )
+
     def compile_func(self, contracts: List[TonProjectConfig] = None):
         """Compile func to code.fif"""
         # Build code
