@@ -22,6 +22,10 @@ class ProjectBootstrapper:
         self.project_help_action = defaultdict(lambda: "")
 
         self.project_help_action['wallet'] = f" and {gr}toncli deploy -n testnet{rs}"
+        self.project_help_action['nft_collection']= f" and {gr} cat README.md{rs} for more information"
+        self.project_help_action['nft_item']      = f" and {gr} build, run_tests (mainly for tesing/dev purposes)"
+        self.project_help_action['jetton_minter'] = f" and {gr} cat README.md{rs} for more information"
+        self.project_help_action['jetton_wallet'] = f" and {gr} build, run_tests (mainly for tesing/dev purposes)"
         self.project_help_action['external_code'] = f" and {gr}cat README.md{rs} for more information"
         self.project_help_action['external_data'] = f" and {gr}cat README.md{rs} for more information"
 
