@@ -1,6 +1,6 @@
 from argparse import ArgumentParser
 import sys
-from toncli.modules.tests.tests import TestsRunner
+from toncli.modules.utils.test.tests import TestsRunner
 from toncli.modules.utils.system.argparse_fix import argv_fix
 
 class RunTestsCommand():
@@ -11,4 +11,5 @@ class RunTestsCommand():
         test_runner = TestsRunner()
         test_runner.run(args.contracts.split() if args.contracts else None,
                         verbose=args.verbose,
-                        output_results=args.output_results)
+                        output_results=args.output_results,
+                        run_tests_old_way=args.old)
