@@ -1,10 +1,10 @@
 from colorama import Fore, Style
 
-
 gr = Fore.GREEN
 bl = Fore.CYAN
 rs = Style.RESET_ALL
 
+
 class TextUtils:
     FIFT_HELP = f'''positional arguments:
       {bl}command{rs}              Which mode to run, can be [interactive, run, sendboc]
@@ -34,6 +34,10 @@ class TextUtils:
 
         {bl}start - create new project structure based on example project  
         {gr}   wallet - create project with v3 wallet example
+        {gr}   nft_collection- project with NFT collection example
+        {gr}   nft_item      - project with single nft item example
+        {gr}   jetton_minter - project with Jetton minter example
+        {gr}   jetton_wallet - project with Jetton wallet example
         {gr}   external_data - create external data usage example
         {gr}   external_code - create external code usage example
 
@@ -68,12 +72,11 @@ class TextUtils:
         {bl}wallet - print addresses of 2 wallets - bounceable wallet and deploy wallet
         {gr}   You can use this command only when wallet is built with commands "toncli build" or "toncli deploy"
 
-        All commands can be found in https://github.com/disintar/toncli/blob/master/docs/commands.md
+        All commands can be found in https://github.com/disintar/toncli/blob/master/docs/advanced/commands.md
 
         {rs}
         Each command have help e.g.: toncli deploy -h
 
         Credits: {gr}disintar.io{rs} team
     '''
-    VERSION_WARNING = """\nIts seems that your local fift and func libs (%s) differs from their actual versions (%s).
-                You can update them automatically using "toncli update_libs" or disable this warning by changing "LIBS_WARNING" to "False" param in cofig\n\n"""
\ No newline at end of file
+    VERSION_WARNING = f""" Its seems that your local fift and func libs ({bl}%s{rs}) differs from their actual versions ({bl}%s{rs}). You can update them automatically using "{bl}toncli update_libs{rs}" or disable this warning by changing {gr}"LIBS_WARNING" to "False"{rs} param in cofig\n\n"""
